==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Image Viewer</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Image Viewer is an image viewing tool with fashion interface and smooth performance.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Images</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Image info</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Basic info</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>This file contains multiple pages, please use Evince to view all pages.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Open Directory</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>You have no permission to view the image</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Image file not found</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Date modified</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Dimension</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>File size</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Date captured</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Exposure mode</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Exposure program</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Exposure time</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Aperture</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Focal length</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Max aperture</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Metering mode</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>White balance</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Flash compensation</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lens model</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Colorspace</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Camera model</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>No scaling</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Fit page to image</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Fit image to page</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Scale to:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimeters</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimeters</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Inches</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Image Position</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Scaling</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Image Settings</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Image Settings</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Blinds</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Switcher</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Sliding</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Ring</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>yyyy/MM/dd HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Input a new name</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Select Directory</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>This directory is disabled to sync</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Add folder</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Sync Directory Management</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>The directory list is empty</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Cancel sync</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>The device has been removed</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>This directory no longer exists</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Calculating...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Image Viewing</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slide show</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>End show</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remove from album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorite</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Unfavorite</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotate clockwise</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotate counterclockwise</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Set as wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Image info</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Previous screen</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Next screen</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>New album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rename</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Exit fullscreen</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zoom in</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zoom out</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Please enter a new shortcut</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Shortcuts</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>View Picture</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Restore Defaults</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slide show</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>End show</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remove from album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorite</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Unfavorite</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotate clockwise</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotate counterclockwise</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Set as wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Image info</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>New album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rename</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Slide Settings</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Switch effect</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duration</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Switch duration</translation>
    </message>
    <message>
        <source>second</source>
        <translation>second</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>My favorite</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Size</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Fit to window</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotate counterclockwise</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotate clockwise</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Back</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Image management</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>My favorite</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Size</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Fit to window</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotate counterclockwise</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotate clockwise</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Unfavorite</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorite</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>No image files found</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Open Image</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Image file not found</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Slide Settings</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Effect</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duration</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Shortcuts</translation>
    </message>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>New album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Timeline</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Add to album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Add to new album</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Exit fullscreen</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slide show</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remove from album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorite</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Unfavorite</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Show navigation window</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Hide navigation window</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotate clockwise</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotate counterclockwise</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Set as wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Image info</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Open Image</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>All images</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rename</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Draw</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.6.orig.tar.xz: deepin-image-viewer-5.9.6/src/translations/deepin-image-viewer.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Image file not found</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Open Image</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Image Viewing</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Exit fullscreen</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extract text</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slide show</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rename</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotate clockwise</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotate counterclockwise</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Set as wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Image info</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zoom in</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zoom out</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Image Viewer</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Image Viewer is an image viewing tool with fashion interface and smooth performance.</translation>
    </message>
</context>
</TS>
